@@ -30,17 +30,12 @@
 #' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #' GNU Lesser General Public License for more details.
 #'
-#' @template etc
-#'
+#' @template ref-matrix_cookbook
 #' @references
 #'
 #' Griewank, Andreas and Walther, Andrea. "Evaluating Derivatives: principles and techniques of algorithmic differentiation."
 #' SIAM (2008).
 #'
-#' Petersen, Kaare Brandt and Pedersen, Michael Syskind. "The Matrix Cookbook."
-#' Technical University of Denmark (2012). 
-#' \url{http://www2.imm.dtu.dk/pubdb/p.php?3274}
-#'
 #' Magnus, Jan R. and Neudecker, H. "Matrix Differential Calculus with Applications in Statistics and Econometrics."
 #' 3rd Edition. Wiley Series in Probability and Statistics: Texts and References Section (2007).
 #'
@@ -52,10 +47,6 @@
 #' Econometric Theory 2 (1986): 157-190.
 #' \url{http://www.janmagnus.nl/papers/JRM014.pdf},
 #'
-#' Fackler, Paul L. "Notes on Matrix Calculus." (2005).
-#' \url{http://www4.ncsu.edu/~pfackler/MatCalc.pdf}
-#'
-#' MM: DO use  @importFrom (whimps use full imports ..) !
 #' @import matrixcalc methods
 #' @importFrom methods cbind2
 #' @importFrom methods rbind2
@@ -78,7 +69,13 @@
 #' 
 #' This package is maintained as a hobby. 
 #'
-NULL
+#' @keywords internal
+#' @aliases madness-package
+"_PACKAGE"
+
+# for some reason this ^-- is now needed by roxygen2.
+# see https://r-pkgs.org/man.html#sec-man-package-doc
+# and https://github.com/r-lib/roxygen2/issues/1491
 
 #' @title News for package \sQuote{madness}:
 #'
@@ -90,6 +87,11 @@ NULL
 #' \newcommand{\CRANpkg}{\href{https://cran.r-project.org/package=#1}{\pkg{#1}}}
 #' \newcommand{\madness}{\CRANpkg{madness}}
 #'
+#' @section \madness{} Version 0.2.8 (2023-08-20) :
+#' \itemize{
+#' \item emergency CRAN release to fix package documentation.
+#' }
+#'
 #' @section \madness{} Version 0.2.7 (2020-02-07) :
 #' \itemize{
 #' \item emergency CRAN release to deal with ellipsis in documentation.
